API Reference
=============

.. autoclass:: geoxgb.GeoXGBRegressor
   :members: fit, predict, feature_importances, partition_feature_importances,
             partition_trace, partition_tree_rules, sample_provenance,
             noise_estimate, cooperation_matrix, cooperation_score,
             cooperation_tensor, local_model, save, load
   :undoc-members: False
   :show-inheritance:

.. autofunction:: geoxgb.GeoXGBMAERegressor

.. autoclass:: geoxgb.GeoXGBClassifier
   :members: fit, predict, predict_proba, feature_importances,
             partition_feature_importances, sample_provenance, noise_estimate,
             cooperation_matrix, cooperation_score, cooperation_tensor,
             local_model, save, load
   :undoc-members: False
   :show-inheritance:
